***************
Source and Sink
***************

.. |br| raw:: html

   <br />

.. automodule:: aristopy.sourceSink

Source
==========

.. autoclass:: Source
   :members:
   :undoc-members:


Sink
==========

.. autoclass:: aristopy.Sink
   :members:
   :undoc-members: